===
Uso
===

Para usar pyrobo en un proyecto::

    >>> from pyrobo.pyrobo import hablame
    >>> hablame()
    ❝¿Pa' qué zapatos si no hay casa, pa' qué hijueputas?❞

                                              Chinga


